==> gcc-4.1.2-x86_64_slamd64-2.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf gcc )
( cd usr/bin ; ln -sf gcc-4.1.2 gcc )
( cd usr/bin ; rm -rf cc )
( cd usr/bin ; ln -sf gcc cc )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gcc )
( cd usr/bin ; ln -sf gcc-4.1.2 x86_64-slamd64-linux-gcc )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gcc-4.1.2 )
( cd usr/bin ; ln -sf gcc-4.1.2 x86_64-slamd64-linux-gcc-4.1.2 )
( cd usr/man/man1 ; rm -rf cc.1.gz )
( cd usr/man/man1 ; ln -sf gcc.1.gz cc.1.gz )
( cd usr/lib64 ; rm -rf libgcc_s.so )
( cd usr/lib64 ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib64 ; rm -rf libmudflap.so.0 )
( cd usr/lib64 ; ln -sf libmudflap.so.0.0.0 libmudflap.so.0 )
( cd usr/lib64 ; rm -rf libmudflap.so )
( cd usr/lib64 ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
( cd usr/lib64 ; rm -rf libmudflapth.so.0 )
( cd usr/lib64 ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so.0 )
( cd usr/lib64 ; rm -rf libmudflapth.so )
( cd usr/lib64 ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so )
( cd usr/lib64 ; rm -rf libssp.so.0 )
( cd usr/lib64 ; ln -sf libssp.so.0.0.0 libssp.so.0 )
( cd usr/lib64 ; rm -rf libssp.so )
( cd usr/lib64 ; ln -sf libssp.so.0.0.0 libssp.so )
( cd usr/lib64 ; rm -rf libobjc.so.1 )
( cd usr/lib64 ; ln -sf libobjc.so.1.0.0 libobjc.so.1 )
( cd usr/lib64 ; rm -rf libobjc.so )
( cd usr/lib64 ; ln -sf libobjc.so.1.0.0 libobjc.so )
( cd usr/lib64/classpath ; rm -rf libgjsmalsa.so.0 )
( cd usr/lib64/classpath ; ln -sf libgjsmalsa.so.0.0.0 libgjsmalsa.so.0 )
( cd usr/lib64/classpath ; rm -rf libgjsmalsa.so )
( cd usr/lib64/classpath ; ln -sf libgjsmalsa.so.0.0.0 libgjsmalsa.so )
( cd lib ; rm -rf cpp )
( cd lib ; ln -sf /usr/bin/cpp cpp )

==> gcc-4.2.3-x86_64_slamd64-1.tgz: install/doinst.sh <==
( cd lib ; rm -rf cpp )
( cd lib ; ln -sf /usr/bin/cpp cpp )
( cd usr/bin ; rm -rf cc )
( cd usr/bin ; ln -sf gcc cc )
( cd usr/bin ; rm -rf gcc )
( cd usr/bin ; ln -sf gcc-4.2.3 gcc )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gcc )
( cd usr/bin ; ln -sf gcc-4.2.3 x86_64-slamd64-linux-gcc )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gcc-4.2.3 )
( cd usr/bin ; ln -sf gcc-4.2.3 x86_64-slamd64-linux-gcc-4.2.3 )
( cd usr/man/man1 ; rm -rf cc.1.gz )
( cd usr/man/man1 ; ln -sf gcc.1.gz cc.1.gz )
( cd usr/lib64 ; rm -rf libssp.so )
( cd usr/lib64 ; ln -sf libssp.so.0.0.0 libssp.so )
( cd usr/lib64 ; rm -rf libmudflap.so.0 )
( cd usr/lib64 ; ln -sf libmudflap.so.0.0.0 libmudflap.so.0 )
( cd usr/lib64 ; rm -rf libmudflapth.so.0 )
( cd usr/lib64 ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so.0 )
( cd usr/lib64 ; rm -rf libobjc.so )
( cd usr/lib64 ; ln -sf libobjc.so.2.0.0 libobjc.so )
( cd usr/lib64 ; rm -rf libgomp.so )
( cd usr/lib64 ; ln -sf libgomp.so.1.0.0 libgomp.so )
( cd usr/lib64 ; rm -rf libmudflapth.so )
( cd usr/lib64 ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so )
( cd usr/lib64 ; rm -rf libssp.so.0 )
( cd usr/lib64 ; ln -sf libssp.so.0.0.0 libssp.so.0 )
( cd usr/lib64 ; rm -rf libgcc_s.so )
( cd usr/lib64 ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib64 ; rm -rf libmudflap.so )
( cd usr/lib64 ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
( cd usr/lib64 ; rm -rf libgomp.so.1 )
( cd usr/lib64 ; ln -sf libgomp.so.1.0.0 libgomp.so.1 )
( cd usr/lib64 ; rm -rf libobjc.so.2 )
( cd usr/lib64 ; ln -sf libobjc.so.2.0.0 libobjc.so.2 )
